@@ -39,10 +39,10 @@ from .responses import (
 )
 from .api import API
 
-VERSION = "0.3.0"
-
+VERSION = "0.3.2"
 
 class Powerwall:
+
     def __init__(
         self,
         endpoint: str,
@@ -136,7 +136,7 @@ class Powerwall:
             self._api.get_powerwalls(), "powerwalls", "powerwalls"
         )
         return [
-            assert_attribute(powerwall, "PackagSerialNumber")
+            assert_attribute(powerwall, "PackageSerialNumber")
             for powerwall in powerwalls
         ]
 
